FirestoreAnimatedGrid<T> class

An AnimatedList widget that is bound to a query

Inheritance

Constructors

FirestoreAnimatedGrid({Key? key, required Query<T> query, required FirestoreAnimatedGridItemBuilder<T> itemBuilder, required int crossAxisCount, double mainAxisSpacing = 4.0, double crossAxisSpacing = 4.0, double childAspectRatio = 1.0, dynamic onLoaded(QuerySnapshot<T>)?, FilterCallback<T>? filter, Widget? defaultChild, ErrorChildBuilder? errorChild, Widget? emptyChild, Axis scrollDirection = Axis.vertical, bool reverse = false, bool debug = false, bool linear = false, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool shrinkWrap = false, EdgeInsets? padding, Duration duration = const Duration(milliseconds: 300)})
Creates a scrolling container that animates items when they are inserted or removed.

Properties

childAspectRatio → double
The ratio of the cross-axis to the main-axis extent of each child.
final
controller → ScrollController?
An object that can be used to control the position to which this scroll view is scrolled.
final
crossAxisCount → int
The number of children in the cross axis.
final
crossAxisSpacing → double
The number of logical pixels between each child along the cross axis.
final
debug → bool
Allows for debug messages relating to FirestoreList operations to be shown on your respective IDE's debug console
final
defaultChild → Widget?
A widget to display while the query is loading. Defaults to a centered CircularProgressIndicator;
final
duration → Duration
The duration of the insert and remove animation.
final
emptyChild → Widget?
A widget to display if the query returns empty. Defaults to a Container();
final
errorChild → ErrorChildBuilder?
A widget to display if an error ocurred. Defaults to a centered Icon with Icons.error and the error itsef;
final
filter → FilterCallback<T>?
Called before any operation with a DocumentSnapshot; If it returns true, then dismisses that DocumentSnapshot from the list
final
hashCode → int
The hash code for this object.
no setterinherited
itemBuilder → FirestoreAnimatedGridItemBuilder<T>
Called, as needed, to build list item widgets.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
linear → bool
This will change onDocumentAdded call to .add instead of .insert, which might help if your query doesn't care about order changes
final
mainAxisSpacing → double
The number of logical pixels between each child along the main axis.
final
onLoaded → dynamic Function(QuerySnapshot<T>)?
Method that gets called once the stream updates with a new QuerySnapshot
final
padding → EdgeInsets?
The amount of space by which to inset the children.
final
physics → ScrollPhysics?
How the scroll view should respond to user input.
final
primary → bool?
Whether this is the primary scroll view associated with the parent PrimaryScrollController.
final
query → Query<T>
A Firestore query to use to populate the animated list
final
reverse → bool
Whether the scroll view scrolls in the reading direction.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → Axis
The axis along which the scroll view scrolls.
final
shrinkWrap → bool
Whether the extent of the scroll view in the scrollDirection should be determined by the contents being viewed.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FirestoreAnimatedGridState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited