FirestoreList<T> class

Handles DocumentChange events, errors and streaming

Inheritance
Mixed-in types

Constructors

FirestoreList({required Query<T> query, DocumentCallback<T>? onDocumentAdded, DocumentCallback<T>? onDocumentRemoved, DocumentCallback<T>? onDocumentChanged, QueryCallback<T>? onLoaded, ValueCallback<T>? onValue, ErrorCallback? onError, FilterCallback<T>? filter, bool linear = false, bool debug = false})

Properties

debug → bool
Whether or not to show debug logs
final
filter → FilterCallback<T>?
Called before any operation with a DocumentSnapshot; If it returns true, then dismisses that DocumentSnapshot from the list
final
first ↔ DocumentSnapshot<T>?
The first element.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<DocumentSnapshot<T>?>
A new Iterator that allows iterating the elements of this Iterable.
no setterinherited
last ↔ DocumentSnapshot<T>?
The last element.
getter/setter pairinherited
length ↔ int
The number of objects in this list.
getter/setter pairoverride
linear → bool
This will change onDocumentAdded call to .add instead of .insert, which might help if your query doesn't care about order changes
final
onDocumentAdded → DocumentCallback<T>?
Called when the Document has been added
final
onDocumentChanged → DocumentCallback<T>?
Called when the Document has changed
final
onDocumentRemoved → DocumentCallback<T>?
Called when the Document has been removed
final
onError → ErrorCallback?
Called when an error is reported (e.g. permission denied)
final
onLoaded → QueryCallback<T>?
Called when the full list has been loaded
final
onValue → ValueCallback<T>?
Called when the data of the list has finished loading
final
query → Query<T>
Firestore query used to populate the list
final
reversed → Iterable<DocumentSnapshot<T>?>
An Iterable of the objects in this list in reverse order.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → DocumentSnapshot<T>?
Checks that this iterable has only one element, and returns that element.
no setterinherited

Methods

add(DocumentSnapshot<T>? element) → void
Adds value to the end of this list, extending the length by one.
inherited
addAll(Iterable<DocumentSnapshot<T>?> iterable) → void
Appends all objects of iterable to the end of this list.
inherited
any(bool test(DocumentSnapshot<T>? element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asMap() → Map<int, DocumentSnapshot<T>?>
An unmodifiable Map view of this list.
inherited
cancelSubscriptions() → void
Cancels all streams that were previously added with listen().
inherited
cast<R>() → List<R>
Returns a view of this list as a list of R instances.
inherited
clear() → void
Removes all objects from this list; the length of the list becomes zero.
override
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → DocumentSnapshot<T>?
Returns the indexth element.
inherited
every(bool test(DocumentSnapshot<T>? element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> f(DocumentSnapshot<T>? element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
fillRange(int start, int end, [DocumentSnapshot<T>? fill]) → void
Overwrites a range of elements with fillValue.
inherited
firstWhere(bool test(DocumentSnapshot<T>? element), {DocumentSnapshot<T>? orElse()?}) → DocumentSnapshot<T>?
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, DocumentSnapshot<T>? element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<DocumentSnapshot<T>?> other) → Iterable<DocumentSnapshot<T>?>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(DocumentSnapshot<T>? element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
getRange(int start, int end) → Iterable<DocumentSnapshot<T>?>
Creates an Iterable that iterates over a range of elements.
inherited
indexOf(Object? element, [int start = 0]) → int
The first index of element in this list.
inherited
indexWhere(bool test(DocumentSnapshot<T>? element), [int start = 0]) → int
The first index in the list that satisfies the provided test.
inherited
insert(int index, DocumentSnapshot<T>? element) → void
Inserts element at position index in this list.
inherited
insertAll(int index, Iterable<DocumentSnapshot<T>?> iterable) → void
Inserts all objects of iterable at position index in this list.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastIndexOf(Object? element, [int? start]) → int
The last index of element in this list.
inherited
lastIndexWhere(bool test(DocumentSnapshot<T>? element), [int? start]) → int
The last index in the list that satisfies the provided test.
inherited
lastWhere(bool test(DocumentSnapshot<T>? element), {DocumentSnapshot<T>? orElse()?}) → DocumentSnapshot<T>?
The last element that satisfies the given predicate test.
inherited
listen(Stream<QuerySnapshot<T>> stream, void onData(QuerySnapshot<T> data), {Function? onError}) → void
Listens to a stream and saves it to the list of subscriptions.
inherited
log(String message) → void
map<T>(T f(DocumentSnapshot<T>? element)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(DocumentSnapshot<T>? combine(DocumentSnapshot<T>? previousValue, DocumentSnapshot<T>? element)) → DocumentSnapshot<T>?
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
remove(Object? element) → bool
Removes the first occurrence of value from this list.
inherited
removeAt(int index) → DocumentSnapshot<T>?
Removes the object at position index from this list.
inherited
removeLast() → DocumentSnapshot<T>?
Removes and returns the last object in this list.
inherited
removeRange(int start, int end) → void
Removes a range of elements from the list.
inherited
removeWhere(bool test(DocumentSnapshot<T>? element)) → void
Removes all objects from this list that satisfy test.
inherited
replaceRange(int start, int end, Iterable<DocumentSnapshot<T>?> newContents) → void
Replaces a range of elements with the elements of replacements.
inherited
retainWhere(bool test(DocumentSnapshot<T>? element)) → void
Removes all objects from this list that fail to satisfy test.
inherited
setAll(int index, Iterable<DocumentSnapshot<T>?> iterable) → void
Overwrites elements with the objects of iterable.
inherited
setRange(int start, int end, Iterable<DocumentSnapshot<T>?> iterable, [int skipCount = 0]) → void
Writes some elements of iterable into a range of this list.
inherited
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
inherited
singleWhere(bool test(DocumentSnapshot<T>? element), {DocumentSnapshot<T>? orElse()?}) → DocumentSnapshot<T>?
The single element that satisfies test.
inherited
skip(int count) → Iterable<DocumentSnapshot<T>?>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(DocumentSnapshot<T>? element)) → Iterable<DocumentSnapshot<T>?>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
sort([int compare(DocumentSnapshot<T>? a, DocumentSnapshot<T>? b)?]) → void
Sorts this list according to the order specified by the compare function.
inherited
sublist(int start, [int? end]) → List<DocumentSnapshot<T>?>
Returns a new list containing the elements between start and end.
inherited
take(int count) → Iterable<DocumentSnapshot<T>?>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(DocumentSnapshot<T>? element)) → Iterable<DocumentSnapshot<T>?>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<DocumentSnapshot<T>?>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<DocumentSnapshot<T>?>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
A string representation of this object.
inherited
where(bool test(DocumentSnapshot<T>? element)) → Iterable<DocumentSnapshot<T>?>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator +(List<DocumentSnapshot<T>?> other) → List<DocumentSnapshot<T>?>
Returns the concatenation of this list and other.
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → DocumentSnapshot<T>?
The object at the given index in the list.
override
operator []=(int index, DocumentSnapshot<T>? value) → void
Sets the value at the given index in the list to value.
override

Constants

TAG → const String