operator [] method
The object at the given index in the list.
The index must be a valid index of this list,
which means that index must be non-negative and
less than length.
Implementation
@override
DocumentSnapshot<T>? operator [](int index) =>
_snapshots.isEmpty || index < 0 || index >= length
? null
: _snapshots[index];